simd

package
v0.0.0-...-155abb7 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Mar 25, 2026 License: GPL-3.0 Imports: 0 Imported by: 0

Documentation

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

func BlendOverBGRA

func BlendOverBGRA(dst, src []byte, pixels int, opacity uint8)

BlendOverBGRA alpha-blends src over dst for pixels BGRA pixels. opacity scales source alpha (0..255).

func CopyBGRA

func CopyBGRA(dst, src []byte, pixels int)

CopyBGRA copies exactly pixels BGRA pixels (4 bytes each) from src to dst. If either slice is too small, it copies the maximum whole-pixel prefix.

func CopyBGRAOpaque

func CopyBGRAOpaque(dst, src []byte, pixels int)

CopyBGRAOpaque copies exactly pixels BGRA pixels from src to dst and forces alpha to 0xFF for each copied pixel.

Types

This section is empty.

Jump to